.. bdbcontrib documentation master file, created by
   sphinx-quickstart on Wed Apr 29 12:22:00 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to bdbcontrib's documentation!
======================================

Bdbcontrib is a collection of utility functions around BayesDB.

Contents:

.. toctree::
   :maxdepth: 2

   bdbcontrib
   internal
   experiments
   predictors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
